# #####################################################################################
#
# Calibrator for Viscous Dampers for Maxwell Model Utilization
#
# Dimitrios G. Lignos, PhD
# McGill University, Quebec, Canada
#
# Date: 02/04/2011
# Revised: 02/25/2011
#
# #####################################################################################

# Define model

wipe all
model BasicBuilder -ndm 2 -ndf 3

# Specify fiber section to assign the Maxwell Model
source SquareSsection.tcl;

#    Damper Area  Damper Length
set Area 12000.0;  set L 5000.0;

#           X       Y
node 1    0.0     0.0
node 2     $L     0.0

# Fixed Conditions
fix 1 1 1 0 
fix 2 0 1 0

# end of fixed conditions

#                 $K        $C      $a    $Area   $Length
set D1 [list   500000.0  100000.0  0.30    $Area        $L];

# Define Maxwell Model Material --------------------------------------------------------

# uniaxialMaterial Maxwell $matTag              $K              $C              $a          $Length
uniaxialMaterial   Maxwell       1   [lindex $D1 0]  [lindex $D1 1]  [lindex $D1 2]  [lindex $D1 4]

#      Section   ID matID                                Width                                 Depth  fiberX fiberY 
SquareSsection    1     1 [expr double(round(pow($Area,0.5)))]  [expr double(round(pow($Area,0.5)))]      10     10

geomTransf Linear 1

# Create            Element  Tag node I node J   #Sections  #Section  CoordTransf
element nonlinearBeamColumn    1      1      2           5         1            1

set LoadPat 1
# Unit Load Pattern in X direction
pattern Plain $LoadPat "Linear" {

# nd FX

load 2 0.01 0.0 0.0

}
 
# Recorders # ------------------------------------------------------------------------
# 
# Force Recorder
#recorder Element 1 -time -file Force.out force
recorder Element -file Force.out -time -ele 1 localForce;
# Displacement Recorder
recorder Element -file Diplacement.out -time -ele 1 section 3 fiber 0.1 0.1 stressStrain


# Displacement Loading Protocol ------------------------------------------------------
set dt1 0.01;

# Displacement Loading Protocol
set fileName2 "ViscousD.tcl";

set Scalefact [expr 1.00000];
# Set Displacement loading history
set DispSeries "Series -dt $dt1 -filePath $fileName2 -factor [expr $Scalefact]"

# Set Applied Direction of loading history
set dir 1

# Set Dynamic Analysis Parameters # ----------------------------------------------------------
# 
# Displacement Control
# Note: In order to calibrate the viscoelastic damper displacement control is used
#       since the damper is time dependent and rate effects are needed to generate force
# Steps:
#       1. A multisupport excitation is used in OpenSees with displacement history input
#       2. The imposed displacement motion is applied to the free end of the damper

pattern MultipleSupport [expr $LoadPat+1] {
groundMotion 2 Plain -disp $DispSeries -int Trapezoidal
#            node     dir   GMotion
imposedMotion   2    $dir         2
}

wipeAnalysis
test EnergyIncr 1.0e-8 50
algorithm Newton
system UmfPack
numberer RCM
constraints Transformation

integrator Newmark 0.5 0.25
analysis Transient
analyze 4841 0.01

wipe all;
# End of File